macro_rules! setup_panic {
($meta:expr) => { ... };
() => { ... };
}Expand description
Register human-panic
The macro should be called from within a function, for example as the first line of the
main() function of the program.
Example
Default metadata!
use human_panic::setup_panic;
setup_panic!();Extend or override default metadata!
use human_panic::setup_panic;
use human_panic::metadata;
setup_panic!(metadata!()
.authors("My Company Support <support@mycompany.com>")
.support("- Open a support request by email to support@mycompany.com")
);