[−][src]Struct human_panic::report::Report
Contains metadata about the crash like the backtrace and information about the crate and operating system. Can be used to be serialized and persisted or printed as information to the user.
Methods
impl Report[src]
pub fn new(
name: &str,
version: &str,
method: Method,
explanation: String,
cause: String
) -> Self[src]
name: &str,
version: &str,
method: Method,
explanation: String,
cause: String
) -> Self
Create a new instance.
pub fn serialize(&self) -> Option<String>[src]
Serialize the Report to a TOML string.
pub fn persist(&self) -> Result<PathBuf, Box<dyn Error + 'static>>[src]
Write a file to disk.